#!/usr/bin/env python

"""
Add users to a MoinMoin wiki.

User details are read from standard input as a tab-separated sequence using the
following format:

USERNAME FULLNAME EMAIL IMAGE-URL

User details are written to standard output in a tab-separated sequence using
the following format:

USERNAME FULLNAME EMAIL IMAGE-URL PASSWORD
"""

from os.path import split
from subprocess import call
import random, string
import sys
import codecs

def randompass():
    return "".join(random.sample(string.ascii_letters, 10))

def add_user(wiki, username, fullname, email, password):
    cmd = ["moin", "--config-dir=%s" % wiki, "account", "create",
        "--name=%s" % username,
        "--email=%s" % email,
        "--password=%s" % password] + \
        (fullname and ["--alias=%s" % fullname] or [])
    call(cmd)

def main():
    progname = split(sys.argv[0])[-1]

    try:
        wiki = sys.argv[1]
    except (IndexError, ValueError):
        print >>sys.stderr, "%s <wiki configuration directory>" % progname
        print >>sys.stderr
        print >>sys.stderr, "Example: %s wiki" % progname
        sys.exit(1)

    stdin = codecs.getreader("utf-8")(sys.stdin)
    stdout = codecs.getwriter("utf-8")(sys.stdout)
    line = stdin.readline()
    while line:
        username, fullname, email, image = line.strip("\n ").split("\t")
        password = randompass()
        add_user(wiki, username, fullname, email, password)
        print >>stdout, "\t".join([username, fullname, email, image, password])

        line = stdin.readline()

if __name__ == "__main__":
    main()

# vim: tabstop=4 expandtab shiftwidth=4
